@@ -4,10 +4,8 @@ PDL::Gaussian -- Gaussian distributions.
 
 =head1 SYNOPSIS
 
-	$a = new PDL::Gaussian([3],[5]);
-	$a->set_covariance(...)
-
-	# XXXX Must improve this interface
+ $a = new PDL::Gaussian([3],[5]);
+ $a->set_covariance(...)
 
 =head1 DESCRIPTION
 
@@ -16,35 +14,35 @@ sets gaussian distributions.
 
 A new set of gaussians is initialized by
 
-	$a = new PDL::Gaussian(xdims,gdims);
+ $a = new PDL::Gaussian(xdims,gdims);
 
 Where I<xdims> is a reference to an array containing the
 dimensions in the space the gaussian
 is in and I<gdimslist> is a reference to an array containing
 the dimensionality of the gaussian space. For example, after
 
-	$a = new PDL::Gaussian([2],[3,4]);
-	$b = new PDL::Gaussian([],[]);
+ $a = new PDL::Gaussian([2],[3,4]);
+ $b = new PDL::Gaussian([],[]);
 
-The variable  $a contains set of 12 (=3*4) 2-Dimensional gaussians
-and $b is the simplest form: one 1D gaussian.
+The variable C<$a> contains set of 12 (=C<3*4>) 2-Dimensional gaussians
+and C<$b> is the simplest form: one 1D gaussian.
 Currently, I<xdims> may containe either zero or one dimensions
-due to limitations of PDL::PP.
+due to limitations of L<PDL::PP|PDL::PP>.
 
 To set the distribution parameters, you can use the routines
 
-	$a->set_covariance($cv);		# covariance matrices
-	$a->set_icovariance($icv);		# inverse covariance matrices
-	$a->set_mu($mu);			# centers
+ $a->set_covariance($cv);     # covariance matrices
+ $a->set_icovariance($icv);   # inverse covariance matrices
+ $a->set_mu($mu);	      # centers
 
-The dimensions of $cv and $icv must be (@xdims,@xdims,@gdims) and
-the dimensions of $mu must be (@xdims,@gdims).
+The dimensions of C<$cv> and C<$icv> must be C<(@xdims,@xdims,@gdims)> and
+the dimensions of C<$mu> must be C<(@xdims,@gdims)>.
 
 Alternatively you can use the routines
 
-	$cv = $a->get_covariance();	# cv = reference to covariance matrix
-	...				# Fuzz around with cv
-	$a->upd_covariance();		# update
+ $cv = $a->get_covariance();  # cv = reference to covariance matrix
+ ...			      # Fuzz around with cv
+ $a->upd_covariance();	      # update
 
 and similarly for C<icovariance> (inverse covariance). The last sub call
 is important to update the other parts of the object.
@@ -52,30 +50,30 @@ is important to update the other parts of the object.
 To get a string representation of the gaussians (most useful for
 debugging) use the routine
 
-	$string = $a->asstr();
+ $string = $a->asstr();
 
 It is possible to calculate the probability or logarithm of probability
 of each of the distributions at some points.
 
-	$a->calc_value($x,$p);
-	$a->calc_lnvalue($x,$p);
+ $a->calc_value($x,$p);
+ $a->calc_lnvalue($x,$p);
 
-Here, $x must have dimensions (ndims,...) and $p must have dimensions
-(gdimslist, ...) where the elipsis represents the same dimensions in
+Here, C<$x> must have dimensions C<(ndims,...)> and C<$p> must have dimensions
+C<(gdimslist, ...)> where the elipsis represents the same dimensions in
 both variables. It is usually advisable to work with the logarithms
 of probabilities to avoid numerical problems.
 
 It is possible to generate the parameters for the gaussians from data.
 The function
 
-	$a->fromweighteddata($data,$wt,$small_covariance);
+ $a->fromweighteddata($data,$wt,$small_covariance);
 
-where data is of dimensions (ndims,npoints) and wt is of dimensions
-(npoints,gdimslist), analyzes the data statistically and gives
-a corresponding gaussian distribution. The parameter $small_covariance
+where C<$data> is of dimensions C<(ndims,npoints)> and C<$wt> is of dimensions
+C<(npoints,gdimslist)>, analyzes the data statistically and gives
+a corresponding gaussian distribution. The parameter C<$small_covariance>
 is the smallest allowed covariance in any direction: if one or more of
 the eigenvalues of the covariance matrix are smaller than this, they
-are automatically set to $small_covariance to avoid singularities.
+are automatically set to C<$small_covariance> to avoid singularities.
 
 =head1 BUGS
 
@@ -94,7 +92,7 @@ to have the '1' dimensions explicitly everywhere.
 Singular distributions are not handled. This should use SVD
 and be able to handle both infinitely narrow and wide dimensions,
 preferably so that infinitely narrow dimensions can be queried
-like $a->relations() or something like that.
+like C<$a->relations()> or something like that.
 
 The routines should, if the user requests for it, check all the dimensions
 of the given arguments for reasonability.
@@ -108,7 +106,6 @@ conditions. For details, see the file COPYING in the PDL
 distribution. If this file is separated from the PDL distribution,
 the copyright notice should be included in the file.
 
-
 =cut
 
 package PDL::Gaussian;
@@ -117,7 +114,7 @@ use PDL::Core '';
 use PDL::Slatec;
 use PDL::Primitive;
 use PDL::Slices;
-use PDL::Lib::LLSQRout;
+# use PDL::Lib::LLSQRout;
 
 sub new {
 	my($type,$ndims,$nfuncs) = @_;
